.. currentmodule:: cratermaker

.. image:: ../_static/counting_icon.svg
    :alt: Counting
    :align: center
    :width: 300px

.. _ug-counting:

Counting
========

The :ref:`Counting <api-counting>` class will be used to tally craters on the surface. It is currently under development.

